Core — BCI-Framework documentation

# Core

class `bci_framework.framework.core.` `Kafka`

  Kafka run on a thread.

  `create_consumer`() → None

    Basic consumer to check stream status and availability.

  `create_produser`() → None

    The produser is used for stream annotations and markers.

  `run`() → None

    Start the produser and consumer for Kafka.

  `set_host`(host: str) → None

    Set the host for kafka.

  `stop`() → None

    Kill the thread.